@@ -97,7 +97,7 @@ class adam_config():
         self.file_ocean_WaterRefInd = 'ADAM_V1_WaterRefractiveIndex_300-4000.txt'
         # absorption coefficient of water
         # from  D. J. Segelstein, "The complex refractive index of water," University of Missouri-Kansas City, (1981). (http://omlc.ogi.edu/spectra/water/data/segelstein81.dat)
-        self.file_ocean_WaterAbs = 'WaterAbsorption_300-4000.txt'
+        self.file_ocean_WaterAbs = 'ADAM_V1_WaterAbsorption_300-4000.txt' # CHANGE_CB 
 
 
 
@@ -241,6 +241,7 @@ class adam_config():
 
             # - snow
             'snow_size_grain'         : 0.12e-3,
+            'chanB'                   : 0, #CHANGE_CB 
             'chanR'                   : 2,
             'chanPIR'                 : 3,
             'chanPIR2'                : 4,
@@ -483,3 +484,4 @@ class AttributeDict(dict):
 #        self.idx_land = idx_land
 #        self.idx_snow = idx_snow
 #        self.idx_ocean = idx_ocean
+
