@@ -299,28 +299,21 @@ def function_brdf_land(ref, ndvi, cfg, sza=None, vza=None, phi=None):
     if vza is None: vza = cfg.vza_std
     if phi is None: phi = cfg.phi_std
 
-
-    #print 'vza shape: %s' % [vza.shape]
-    #print 'phi shape: %s' % [phi.shape]
-
     # syncronise shapes, this is neccessary because the shape of vza and phi need to always be the same
     vza_meshed, phi_meshed = vza, phi
     if vza.shape != phi.shape:
-        vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        #vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        phi_meshed, vza_meshed = np.meshgrid(phi, vza) # CHANGE_CB
+        vza_meshed = vza_meshed.ravel()                # CHANGE_CB
+        phi_meshed = phi_meshed.ravel()                # CHANGE_CB
 
 
     # BRDF fonctions
-    #f1 = brdf_land_f1(sza,vza_meshed,phi_meshed)
-    #f2 = brdf_land_f2(sza,vza_meshed,phi_meshed)
-#    the problem comes from the fact that f1 and f2 are (1,47) arrays.
-#    f1[0] and f2[0] are arrays of 47 elements, which can not be multiplied
-#    by a ref of 3701 elements.
-#    therefore, as we have said that sza is only a float, I just changed (line 312):
-    f1 = brdf_land_f1(sza,vza_meshed,phi_meshed).ravel()
-    f2 = brdf_land_f2(sza,vza_meshed,phi_meshed).ravel()
+    f1 = brdf_land_f1(sza,vza_meshed,phi_meshed) #.ravel()                # CHANGE_CB
+    f2 = brdf_land_f2(sza,vza_meshed,phi_meshed) #.ravel()                # CHANGE_CB
 
-    #print 'f1 shape: %s' % [f1.shape]
-    #print 'f2 shape: %s' % [f2.shape]
+    # print 'f1 shape: %s' % [f1.shape]
+    # print 'f2 shape: %s' % [f2.shape]
 
     # Scaling of the R and V coefficients as a function of NDVI
     #ndvi = (ref_MODIS[Cland.chanPIR]-ref_MODIS[Cland.chanR]) / (ref_MODIS[Cland.chanPIR]+ref_MODIS[Cland.chanR])
@@ -332,13 +325,11 @@ def function_brdf_land(ref, ndvi, cfg, sza=None, vza=None, phi=None):
     R = cfg.land.alpha_RV * Rnir + (1-cfg.land.alpha_RV)*Rr
     V = cfg.land.alpha_RV * Vnir + (1-cfg.land.alpha_RV)*Vr
 
-
     # BRDF, # why would this ever happen ?
     if f1.shape == () or ref.shape == ():
         brdf = ref*(1+R*f1+V*f2)
     else:
         brdf = np.zeros( (ref.shape[0], len(vza), len(phi) ),np.float32)
-        #print 'brdf shape: %s' % [brdf.shape]
         if ref.shape[0] > f1.shape[0]:
             for i in range(f1.shape[0]):
                 calc = ref[:]*(1+R*f1[i]+V*f2[i])
@@ -347,12 +338,8 @@ def function_brdf_land(ref, ndvi, cfg, sza=None, vza=None, phi=None):
             # for each waveband
             for i in range(ref.shape[0]):
                 calc = ref[i]*(1+R*f1[:]+V*f2[:])
-                #print '2calc shape: %s' % [calc.shape]
-                #print '2brdf shape: %s' % [brdf[i,:].shape]
                 brdf[i,:] = calc.reshape(brdf[i,:].shape)
 
-
-
     return brdf
 # END function_brdf_land
 # ===================================================================
@@ -503,7 +490,7 @@ def function_brdf_ocean(ref, wind_speed, cfg, sza=None, vza=None, phi=None, lmbd
     ref_sp = ocean_specular_reflectance(xi,nwater)
 
     # only if a broad spectral domain is considered
-    if do_spectral_averaging == True:  
+    if do_spectral_averaging == True:
         ans = np.zeros((1,xi.shape[0]), np.float)
         for i in range(xi.shape[0]):
             ans[0,i] = np.average(ref_sp[:,i])
@@ -903,3 +890,4 @@ def ocean_specular_reflectance( ti, n):
     return rho_sp
 # END ocean_specular_reflectance
 # ===================================================================
+
